let traces={"Age": {"function_name": "Age", "filename": "demo/demo.py", "caller": "<module>", "caller_line_num": 3, "caller_file": "demo/demo.py", "line_num": 3, "call_args": {}, "call_number": 1, "class_name": "None", "calls": [], "return_type": "NoneType", "docstring": null}, "main": {"function_name": "main", "filename": "demo/demo.py", "caller": "<module>", "caller_line_num": 56, "caller_file": "demo/demo.py", "line_num": 37, "call_args": {"yob": "int", "weight": "int", "height": "float"}, "call_number": 2, "class_name": "None", "calls": ["Age.__init__", "Age.get_age", "calculate_bmi"], "return_type": "dict", "docstring": "\n    Generate the health credentials of a user based on input.\n        Args:\n            yob: The year of birth.\n            wieght: in kilograms.\n            height: in meters.\n        Returns:\n            age, bmi: as a dictionary.\n    "}, "Age.__init__": {"function_name": "Age.__init__", "filename": "demo/demo.py", "caller": "main", "caller_line_num": 47, "caller_file": "demo/demo.py", "line_num": 8, "call_args": {"self": "Age"}, "call_number": 3, "class_name": "Age", "calls": [], "return_type": "NoneType", "docstring": "\n    test Ager DOCstring\n    "}, "Age.get_age": {"function_name": "Age.get_age", "filename": "demo/demo.py", "caller": "main", "caller_line_num": 48, "caller_file": "demo/demo.py", "line_num": 11, "call_args": {"self": "Age", "yob": "int"}, "call_number": 4, "class_name": "Age", "calls": [], "return_type": "int", "docstring": "\n        Calculate age using date of birth.\n            Args:\n                yob: The year of birth.\n            Returns:\n                age: indicates how old the person is.\n        "}, "calculate_bmi": {"function_name": "calculate_bmi", "filename": "demo/demo.py", "caller": "main", "caller_line_num": 49, "caller_file": "demo/demo.py", "line_num": 24, "call_args": {"weight": "int", "height": "float"}, "call_number": 5, "class_name": "None", "calls": [], "return_type": "float", "docstring": "\n    Calculate body mass index.\n        Args:\n            wieght: in kilograms.\n            height: in meters.\n        Returns:\n            bmi: body mass index.\n    "}, "entry_function": "main"}