#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['scroll']

package_data = \
{'': ['*'], 'scroll': ['templates/*']}

install_requires = \
['click']

entry_points = \
{'console_scripts': ['scroll = scroll:scroll']}

setup(name='scroll',
      version='2020.7.22',
      description='SCROLL: Automatically generates documentation and unit-tests for python programs',
      author='Edison Abahurire',
      author_email='abahedison@gmail.com',
      url='https://github.com/SimiCode/scroll',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
